<?php
// $Id: toolbar.templates.html.php,v 1.5 2003/11/09 16:38:03 rcastley Exp $
/**
* Template toolbar HTML
* @package Mambo Open Source
* @Copyright (C) 2000 - 2003 Miro International Pty Ltd
* @ All rights reserved
* @ Mambo Open Source is Free Software
* @ Released under GNU/GPL License: http://www.gnu.org/copyleft/gpl.html
* @version $Revision: 1.5 $
**/

class MENU_templates {
	function DEFAULT_MENU() {
		mosMenuBar::startTable();
		mosMenuBar::publishList();
		//mosMenuBar::unpublishList();
		mosMenuBar::divider();
		mosMenuBar::addNew();
		mosMenuBar::editHtml( 'edit_source' );
		mosMenuBar::editCss( 'edit_css' );
		mosMenuBar::deleteList();
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
 	function VIEW_MENU(){
		mosMenuBar::startTable();
		mosMenuBar::back();
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
	
	function NEW_MENU() {
		mosMenuBar::startTable();
		mosMenuBar::save();
		mosMenuBar::divider();
		mosMenuBar::cancel();
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}

	function EDIT_SOURCE_MENU(){
		mosMenuBar::startTable();
		mosMenuBar::save( 'save_source' );
		mosMenuBar::cancel();
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}

	function EDIT_CSS_MENU(){
		mosMenuBar::startTable();
		mosMenuBar::save( 'save_css' );
		mosMenuBar::cancel();
		mosMenuBar::spacer();
		mosMenuBar::endTable();
	}
}
?>
